<?php
/**
 * Behavior that provides named scopes titled "published" and "unpublished"
 *
 * Credit: http://www.yiiframework.com/wiki/30/how-to-add-a-named-scope-to-activerecords-with-a-behavior/
 *
 * @license:
 * Copyright (c) 2012, Boaz Rymland
 * All rights reserved.
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 * - Redistributions of source code must retain the above copyright notice, this list of conditions and the following
 *      disclaimer.
 * - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following
 *      disclaimer in the documentation and/or other materials provided with the distribution.
 * - The names of the contributors may not be used to endorse or promote products derived from this software without
 *      specific prior written permission.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */
class PcPublishedBehavior extends CActiveRecordBehavior {
	/**
	 * Named scope to narrow down the records that are in status 'published'.
	 * @return CActiveRecord
	 */
	public function published() {
		$owner = $this->owner;
		$this->owner->getDbCriteria()->mergeWith(array('condition' => 'status=' . $owner::STATUS_PUBLISHED));
		return $this->owner;
	}

	/**
	 * Named scope to narrow down the records that are NOT in status 'published'.
	 * @return CActiveRecord
	 */
	public function unpublished() {
		$owner = $this->owner;
		$this->owner->getDbCriteria()->mergeWith(array('condition' => 'status!=' . $owner::STATUS_PUBLISHED));
		return $this->owner;
	}
}